@@ -16,8 +16,10 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains SFTP sensor."""
+from __future__ import annotations
+
 from datetime import datetime
-from typing import TYPE_CHECKING, Optional, Sequence
+from typing import TYPE_CHECKING, Sequence
 
 from paramiko.sftp import SFTP_NO_SUCH_FILE
 
@@ -40,8 +42,8 @@ class SFTPSensor(BaseSensorOperator):
     """
 
     template_fields: Sequence[str] = (
-        'path',
-        'newer_than',
+        "path",
+        "newer_than",
     )
 
     def __init__(
@@ -49,39 +51,40 @@ class SFTPSensor(BaseSensorOperator):
         *,
         path: str,
         file_pattern: str = "",
-        newer_than: Optional[datetime] = None,
-        sftp_conn_id: str = 'sftp_default',
+        newer_than: datetime | None = None,
+        sftp_conn_id: str = "sftp_default",
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
         self.path = path
         self.file_pattern = file_pattern
-        self.hook: Optional[SFTPHook] = None
+        self.hook: SFTPHook | None = None
         self.sftp_conn_id = sftp_conn_id
-        self.newer_than: Optional[datetime] = newer_than
-        self.actual_file_to_check = self.path
+        self.newer_than: datetime | None = newer_than
 
-    def poke(self, context: 'Context') -> bool:
+    def poke(self, context: Context) -> bool:
         self.hook = SFTPHook(self.sftp_conn_id)
-        self.log.info(f"Poking for {self.path}, with pattern {self.file_pattern}")
+        self.log.info("Poking for %s, with pattern %s", self.path, self.file_pattern)
 
         if self.file_pattern:
             file_from_pattern = self.hook.get_file_by_pattern(self.path, self.file_pattern)
             if file_from_pattern:
-                self.actual_file_to_check = file_from_pattern
+                actual_file_to_check = file_from_pattern
             else:
                 return False
+        else:
+            actual_file_to_check = self.path
 
         try:
-            mod_time = self.hook.get_mod_time(self.actual_file_to_check)
-            self.log.info('Found File %s last modified: %s', str(self.actual_file_to_check), str(mod_time))
+            mod_time = self.hook.get_mod_time(actual_file_to_check)
+            self.log.info("Found File %s last modified: %s", str(actual_file_to_check), str(mod_time))
         except OSError as e:
             if e.errno != SFTP_NO_SUCH_FILE:
                 raise e
             return False
         self.hook.close_conn()
         if self.newer_than:
-            _mod_time = convert_to_utc(datetime.strptime(mod_time, '%Y%m%d%H%M%S'))
+            _mod_time = convert_to_utc(datetime.strptime(mod_time, "%Y%m%d%H%M%S"))
             _newer_than = convert_to_utc(self.newer_than)
             return _newer_than <= _mod_time
         else:
